
=head1 NAME

VCS::Imp - notes for the Imp (psuedo) implementation

=head1 SYNOPSIS

    use VCS;
    $file = VCS::File->new('/imprepos/project/Makefile');

=head1 DESCRIPTION

Currently, the user needs to ensure that their environment has the 
Imp toolset available.
On Unix like environments ensure that the C<$PATH> environment variable
has the appropriate directory listed.

=head1 AVAILABILITY 

VCS::Imp is available from CPAN.

=head1 COPYRIGHT 

Copyright (c) 2001 A.U. Thor. All rights reserved. This program is free 
software; you can redistribute it and/or modify it under the same terms
as Perl itself. 

=head1 SEE ALSO

L<VCS>.

=cut
